﻿import QtQuick 2.8
import QtQuick.Layouts 1.1
import QtQuick.Controls 2.5
import org.kde.plasma.components 2.0
import org.kde.plasma.core 2.0
import org.kde.plasma.plasmoid 2.0
import QtQuick.Controls.Styles 1.4

// kde plasma widget google search 

Item {
    id: compactItem
    width: 250
    anchors.fill: parent
    
    property bool inTray
    property int layoutType: inTray ? 2 : main.layoutType
    
    property double parentWidth: parent.width
    property double parentHeight: parent.height
    
    property double partRatio: layoutType === 2 ? 1 : (4 / 3)
    
    property double partWidth: 0
    property double partHeight: 0
    
    property double widgetWidth: 0
    property double widgetHeight: 0
    
    onParentWidthChanged: {
        computeWidgetSize()
    }
    
    onParentHeightChanged: {
        computeWidgetSize()
    }
    
    onLayoutTypeChanged: {
        computeWidgetSize()
    }
    
    function computeWidgetSize() {
        if (layoutType === 0) {
            partWidth = vertical ? (parentWidth / 2) : parentHeight * partRatio
            partHeight = partWidth / partRatio
            widgetWidth = partWidth * 2
            widgetHeight = partHeight
        } else if (layoutType === 1) {
            partWidth = vertical ? parentWidth : (parentHeight / 2) * partRatio
            partHeight = partWidth / partRatio
            widgetWidth = partWidth
            widgetHeight = partHeight * 2
        } else if (layoutType === 2) {
            partWidth = vertical ? parentWidth : parentHeight
            partHeight = partWidth
            widgetWidth = partWidth
            widgetHeight = partHeight
        }
    }
    
    property double fontPixelSize: partHeight * (layoutType === 2 ? 0.7 : 0.7)
    

Item
{
    id: root
    Plasmoid.backgroundHints: "NoBackground"
    
    Image {
        id:img1
        width: 24
        height: 24
        source: "/usr/share/icons/breeze/actions/24/system-search.svg"
        anchors.verticalCenter: tf.verticalCenter
        anchors.left: root.left
        anchors.leftMargin: 10
        anchors.rightMargin: 10
    }
    
    TextField {  // search box
        id:tf
        width:256
        height:28
        placeholderText: qsTr("Google Search...")
        anchors.top:root.top
        anchors.rightMargin:20
        anchors.left:img1.right
        opacity: .45
        onAccepted:  {
                Qt.openUrlExternally("http://www.google.com/search?q="+tf.text) 
                tf.text="" // clear search field
                focus:false
        }
        focus:true
        style: TextFieldStyle {
            textColor:  "white"
            placeholderTextColor:"gray"
            background: Rectangle {
                radius: 8
                border.color: "gray"
                border.width: 2
                color: "black"
            }
        }
    }
}
}
